@@ -1,7 +1,5 @@
 import os
 
-from pickle import dump, load
-
 from jkUnicode import UniInfo
 from jkUnicode.tools.jsonhelpers import dict_from_file
 
@@ -12,6 +10,7 @@ from typing import Any, Dict, List, Optional, Set
 IGNORED_UNICODES = [
     # Minute and second appear in lots of language definitions in CLDR, but are
     # not in very many fonts.
+    0x2011,  # non-breaking hyphen
     0x2032,  # minute
     0x2033,  # second
 ]
@@ -348,7 +347,7 @@ class Orthography:
         if self.info is None:
             cmap_set = set()
         else:
-            cmap_set = set(self.info.cmap)
+            cmap_set = self.info.codepoints
         # Check for missing chars
         self.missing_base = self.unicodes_base - cmap_set
         self.missing_optional = self.unicodes_optional - cmap_set
@@ -480,28 +479,7 @@ class OrthographyInfo:
         data_path = os.path.join(
             os.path.dirname(os.path.realpath(__file__)), "json"
         )
-        pickled_path = os.path.join(data_path, "language_characters.pickle")
-        if os.path.exists(pickled_path):
-            # print("Unpickling language data...")
-            # start = time()
-            with open(pickled_path, "rb") as f:
-                master = load(f)
-            # stop = time()
-            # print(f"...done in {stop - start}s.")
-        else:
-            # print("Loading JSON language data...")
-            # start = time()
-            master = dict_from_file(data_path, "language_characters")
-            # stop = time()
-            # print(f"...done in {stop - start}s.")
-            try:
-                with open(pickled_path, "wb") as f:
-                    dump(master, f)
-            except:
-                # Writing the pickled file may fail on a read-only system,
-                # just ignore it
-                pass
-
+        master = dict_from_file(data_path, "language_characters")
         self.ignored_unicodes = set(IGNORED_UNICODES)
         self.orthographies = []
         self._index = {}
@@ -525,27 +503,42 @@ class OrthographyInfo:
         self._territory_names = dict_from_file(data_path, "territories")
 
         self._cmap: Dict[int, str] = {}
+        self._codepoints: Set[int] = set()
         self._reverse_cmap: Dict[int, List[int]] = {}
 
     @property
-    def cmap(self) -> dict:
+    def cmap(self) -> Dict[int, str]:
         """
-        The unicode to glyph name mapping, a dictionary. When you set the cmap,
-        it is scanned against all orthographies belonging to the Orthography
-        Info object.
+        The codepoint to glyph name mapping. When you set the cmap, it is
+        scanned against all orthographies belonging to the OrthographyInfo
+        object.
+
+        You set the cmap by passing a dictionary, usually from a font. E.g.:
+
+        TTFont("myfont.ttf")
+        o = OrthographyInfo()
+        o.cmap = TTFont("myfont.ttf").getBestCmap()
         """
         return self._cmap
 
     @cmap.setter
-    def cmap(self, value: Optional[dict] = None) -> None:
+    def cmap(self, value: Optional[Dict[int, str]] = None) -> None:
         if value is None:
-            self._cmap = {}
+            self._cmap = dict()
+            self._codepoints = set()
             for o in self.orthographies:
                 o.forget_cmap()
         else:
             self._cmap = value
-            for o in self.orthographies:
-                o.scan_cmap()
+            newCodepoints = set(value)
+            if newCodepoints != self._codepoints:
+                self._codepoints = newCodepoints
+                for o in self.orthographies:
+                    o.scan_cmap()
+    
+    @property
+    def codepoints(self) -> Set[int]:
+        return self._codepoints
 
     def build_reverse_cmap(self) -> None:
         """
