@@ -5,7 +5,8 @@ from jkUnicode import getUnicodeChar
 
 from typing import Any, List
 
-ur = compile("^u([0-9A-F]+)")  # Regex to match unicode sequences, e.g. \u0302
+# Regex to match unicode sequences, e.g. \u0302
+unicode_seq = compile("^u([0-9A-F]+)")
 
 
 class Buffer:
@@ -24,12 +25,13 @@ class Buffer:
         return v
 
     def __get__(self) -> str:
-        m = ur.search(self._str)
-        if m:
-            return getUnicodeChar(int(m.groups(0)[0], 16))
-        else:
+        m = unicode_seq.search(self._str)
+        if m is None:
             return self._str
 
+        group = str(m.groups(0)[0])
+        return getUnicodeChar(int(group, 16))
+
     def __repr__(self) -> str:
         return self._str
 
@@ -122,15 +124,15 @@ def filtered_char_list(xml_char_list: str, debug: bool = False) -> List[str]:
 
     filtered.add(buf.flush())
 
-    filtered = filtered.get()
+    result = filtered.get()
 
     # Expand ranges
     final = []
     f: str
-    for i, f in enumerate(filtered):
+    for i, f in enumerate(result):
         if f == "RANGE":
-            start = ord(filtered[i - 1]) + 1
-            end = ord(filtered[i + 1])
+            start = ord(result[i - 1]) + 1
+            end = ord(result[i + 1])
             # print("RANGE: %04X, %04X" % (start, end))
             for g in range(start, end):
                 # print("0x%04X" % g)
